@@ -48,7 +48,7 @@ def plot_lifetimes(lifetimes, event_observed=None, birthtimes=None, order=False)
 
 def shaded_plot(x, y, y_upper, y_lower, **kwargs):
     ax = kwargs.pop('ax', plt.gca())
-    base_line, = ax.plot(x, y, **kwargs)
+    base_line, = ax.plot(x, y, drawstyle='steps-post', **kwargs)
     ax.fill_between(x, y_lower, y_upper, facecolor=base_line.get_color(), alpha=0.25)
     return
 
@@ -86,6 +86,8 @@ def plot_regressions(self):
             y = get_loc(self.cumulative_hazards_[column]).values
             y_upper = get_loc(self.confidence_intervals_[column].ix['upper']).values
             y_lower = get_loc(self.confidence_intervals_[column].ix['lower']).values
+            print(kwargs.get('label'))
+            print(column)
             shaded_plot(x, y, y_upper, y_lower, ax=kwargs["ax"], label=coalesce(kwargs.get('label'),column))
 
         if legend:
